Index: channels/chan_skinny.c
===================================================================
--- channels/chan_skinny.c	(revision 76219)
+++ channels/chan_skinny.c	(working copy)
@@ -1251,6 +1251,7 @@
 static struct skinny_line *find_line_by_name(const char *dest)
 {
 	struct skinny_line *l;
+	struct skinny_line *tmp = NULL;
 	struct skinny_device *d;
 	char line[256];
 	char *at;
@@ -1258,30 +1259,41 @@
 
 	ast_copy_string(line, dest, sizeof(line));
 	at = strchr(line, '@');
-	if (!at) {
-		ast_log(LOG_NOTICE, "Device '%s' has no @ (at) sign!\n", dest);
-		return NULL;
-	}
-	*at++ = '\0';
+	if (at)
+		*at++ = '\0';
 	device = at;
 	ast_mutex_lock(&devicelock);
 	for (d = devices; d; d = d->next) {
-		if (!strcasecmp(d->name, device)) {
+		if (ast_strlen_zero(device)) {
+			/* This is a match, since we're checking for line on every device. */
+		} else if (!strcasecmp(d->name, device)) {
 			if (skinnydebug)
-				ast_verbose("Found device: %s\n", d->name);
-			/* Found the device */
-			for (l = d->lines; l; l = l->next) {
-				/* Search for the right line */
-				if (!strcasecmp(l->name, line)) {
+				ast_verbose(VERBOSE_PREFIX_2 "Found device: %s\n", d->name);
+		} else
+			continue;
+
+		/* Found the device (or we don't care which device) */
+		for (l = d->lines; l; l = l->next) {
+			/* Search for the right line */
+			if (!strcasecmp(l->name, line)) {
+				if (ast_strlen_zero(device)) {
+					if (tmp) {
+						ast_verbose(VERBOSE_PREFIX_2 "Ambiguous line name: %s\n", line);
+						ast_mutex_unlock(&devicelock);
+						return NULL;
+					} else {
+						tmp = l;
+					}
+				}else {
 					ast_mutex_unlock(&devicelock);
 					return l;
 				}
 			}
 		}
 	}
-	/* Device not found */
+	/* Device not found or no device specified and name is unique */
 	ast_mutex_unlock(&devicelock);
-	return NULL;
+	return tmp;
 }
 
 /* It's quicker/easier to find the subchannel when we know the instance number too */
